@@ -260,32 +260,32 @@ ICP12_MKLINKS() {
     ICP12_COPY_FILE $FULL_PROGRAM_PATH $INTEL_COMPLIB_DIR/linux/bin
 
     # check which version directories "lib", "include" points to and try to set up all links in bin by binaries from this version
-    CPRO_VER_SET=$(readlink $INTEL_COMPLIB_2018_LIB_DIR | sed "s/^.*\(compilers_and_libraries_2018.[0-9]\.[0-9][0-9][0-9]\).*$/\1/g")
+    CPRO_VER_SET=$(readlink $INTEL_COMPLIB_2019_LIB_DIR | sed "s/^.*\(compilers_and_libraries_2019.[0-9]\.[0-9][0-9][0-9]\).*$/\1/g")
     if [ -n "$CPRO_VER_SET" ]; then
         PACKAGEID="$CPRO_VER_SET"
         PKG_INSTALL_DESTINATION="$TOP_INTEL_DIR/$PACKAGEID"
     fi
     
     #create folder for ia32 links
-    [ -d $PKG_INSTALL_DESTINATION/linux/bin/ia32 ] && mkdir -p $INTEL_COMPLIB_2018_BIN_DIR/ia32
+    [ -d $PKG_INSTALL_DESTINATION/linux/bin/ia32 ] && mkdir -p $INTEL_COMPLIB_2019_BIN_DIR/ia32
     #create folder for intel64 links
-    [ -d $PKG_INSTALL_DESTINATION/linux/bin/intel64 ] && mkdir -p $INTEL_COMPLIB_2018_BIN_DIR/intel64
+    [ -d $PKG_INSTALL_DESTINATION/linux/bin/intel64 ] && mkdir -p $INTEL_COMPLIB_2019_BIN_DIR/intel64
 	            	
     # create links for binary and non-env script program files
     for THIS_FILE in $INTEL_PROGRAM_FILES_LIST
     do
         
-        # creating links on files in INTEL_COMPLIB_2018_BIN_DIR dir for ia32 architecture
-        pushd $INTEL_COMPLIB_2018_BIN_DIR/ia32 &> /dev/null
-        ICP12_CREATE_FILE_LINK ../../../../$PACKAGEID/linux/bin/ia32/$THIS_FILE $INTEL_COMPLIB_2018_BIN_DIR/ia32/$THIS_FILE
+        # creating links on files in INTEL_COMPLIB_2019_BIN_DIR dir for ia32 architecture
+        pushd $INTEL_COMPLIB_2019_BIN_DIR/ia32 &> /dev/null
+        ICP12_CREATE_FILE_LINK ../../../../$PACKAGEID/linux/bin/ia32/$THIS_FILE $INTEL_COMPLIB_2019_BIN_DIR/ia32/$THIS_FILE
         popd &>/dev/null
-        pushd $INTEL_COMPLIB_2018_BIN_DIR/intel64 &> /dev/null
-        ICP12_CREATE_FILE_LINK ../../../../$PACKAGEID/linux/bin/intel64/$THIS_FILE $INTEL_COMPLIB_2018_BIN_DIR/intel64/$THIS_FILE
+        pushd $INTEL_COMPLIB_2019_BIN_DIR/intel64 &> /dev/null
+        ICP12_CREATE_FILE_LINK ../../../../$PACKAGEID/linux/bin/intel64/$THIS_FILE $INTEL_COMPLIB_2019_BIN_DIR/intel64/$THIS_FILE
         popd &>/dev/null
         
 		# creating links on files in INTEL_BIN_DIR dir
         pushd $INTEL_BIN_DIR &>/dev/null
-        ICP12_CREATE_FILE_LINK ../compilers_and_libraries_2018/linux/bin/$ARCH/$THIS_FILE $INTEL_BIN_DIR/$THIS_FILE
+        ICP12_CREATE_FILE_LINK ../compilers_and_libraries_2019/linux/bin/$ARCH/$THIS_FILE $INTEL_BIN_DIR/$THIS_FILE
         popd &> /dev/null
     done
 
@@ -297,11 +297,11 @@ ICP12_MKLINKS() {
         if [ "x$(echo $THIS_FILE | grep compilervars)" != "x" ]; then
             filetarget=$(find $PKG_INSTALL_DESTINATION -name "$THIS_FILE" -type f)
             filedestination=$(echo ${THIS_FILE} | sed -e"s/_global//g")
-            cp -p ${filetarget} "$INTEL_COMPLIB_2018_BIN_DIR/${filedestination}" &>/dev/null
-            VERBOSE_PRINT "Copied $THIS_FILE to $INTEL_COMPLIB_2018_BIN_DIR/${filedestination}"
+            cp -p ${filetarget} "$INTEL_COMPLIB_2019_BIN_DIR/${filedestination}" &>/dev/null
+            VERBOSE_PRINT "Copied $THIS_FILE to $INTEL_COMPLIB_2019_BIN_DIR/${filedestination}"
 
             pushd $INTEL_BIN_DIR &>/dev/null
-            ICP12_CREATE_FILE_LINK ../compilers_and_libraries_2018/linux/bin/${filedestination} $INTEL_BIN_DIR/${filedestination}
+            ICP12_CREATE_FILE_LINK ../compilers_and_libraries_2019/linux/bin/${filedestination} $INTEL_BIN_DIR/${filedestination}
             popd &> /dev/null
         else
             # don't create ifortvars.[c]sh if fortran isn't installed
@@ -330,7 +330,7 @@ ICP12_MKLINKS() {
     done
     
     # support of SC foldermap
-    pushd $INTEL_COMPLIB_2018_DIR &>/dev/null
+    pushd $INTEL_COMPLIB_2019_DIR &>/dev/null
     ICP12_CREATE_FILE_LINK "../$PACKAGEID/foldermap.sc.xml" "foldermap.sc.xml"
     popd &>/dev/null
     # support of SC foldermap - end
@@ -342,8 +342,8 @@ ICP12_RMLINKS() {
     VERBOSE_PRINT "ICP12_RMLINKS()"
 
     # support of SC foldermap
-    if [ -e "${INTEL_COMPLIB_2018_DIR}/foldermap.sc.xml" ] ; then
-        rm $RM_OPTIONS "${INTEL_COMPLIB_2018_DIR}/foldermap.sc.xml" &>/dev/null
+    if [ -e "${INTEL_COMPLIB_2019_DIR}/foldermap.sc.xml" ] ; then
+        rm $RM_OPTIONS "${INTEL_COMPLIB_2019_DIR}/foldermap.sc.xml" &>/dev/null
     fi
     # support of SC foldermap - end
 
@@ -396,7 +396,7 @@ VERBOSE_PRINT() {
 FIND_LATEST_PROD_INSTANCE () {
     VERBOSE_PRINT "FIND_LATEST_PROD_INSTANCE()"
 
-    CPRO_INSTALLED_VERSIONS=$(ls -A $TOP_INTEL_DIR | grep 'compilers_and_libraries_' | sed 's/compilers_and_libraries_//g' | grep -e '2018' | grep -ve '^2018$' | sort -gr)
+    CPRO_INSTALLED_VERSIONS=$(ls -A $TOP_INTEL_DIR | grep 'compilers_and_libraries_' | sed 's/compilers_and_libraries_//g' | grep -e '2019' | grep -ve '^2019$' | sort -gr)
     local CPRO_LATEST_PACKAGE_NUMBER=$(echo "$CPRO_INSTALLED_VERSIONS" | cut -d'.' -f3 | sort -gr | head -1)
 
     if [ -z "$CPRO_INSTALLED_VERSIONS" ]; then
@@ -404,7 +404,7 @@ FIND_LATEST_PROD_INSTANCE () {
         return 1
     else
         # Since versions are sorted in descending type, we can take the first line for getting latest version
-        LATEST_VER=$(echo "$CPRO_INSTALLED_VERSIONS" | grep -e "^2018\.[0-9]*\.${CPRO_LATEST_PACKAGE_NUMBER}$")
+        LATEST_VER=$(echo "$CPRO_INSTALLED_VERSIONS" | grep -e "^2019\.[0-9]*\.${CPRO_LATEST_PACKAGE_NUMBER}$")
     fi
 
     VERBOSE_PRINT "LATEST_VER=$LATEST_VER"
@@ -487,24 +487,24 @@ ICP12_INIT() {
 
     LINK_STRUCT="\
 d n  INTEL_BIN_DIR                              \$TOP_INTEL_DIR/bin;\
-d n  INTEL_COMPLIB_2018_DIR                     \$TOP_INTEL_DIR/compilers_and_libraries_2018;\
-d n  INTEL_COMPLIB_2018_Lin_DIR                 \$TOP_INTEL_DIR/compilers_and_libraries_2018/linux;\
-d n  INTEL_COMPLIB_2018_BIN_DIR                 \$INTEL_COMPLIB_2018_Lin_DIR/bin;\
-l n  INTEL_COMPLIB_DIR                          \$TOP_INTEL_DIR/compilers_and_libraries         compilers_and_libraries_2018;\
-l n  INTEL_COMPLIB_2018_PKG_BIN_DIR             \$INTEL_COMPLIB_2018_Lin_DIR/pkg_bin            ../../$PACKAGEID/linux/bin;\
-l n  INTEL_COMPLIB_2018_LIB_DIR                 \$INTEL_COMPLIB_2018_Lin_DIR/lib                ../../$PACKAGEID/linux/compiler/lib;\
-l n  INTEL_COMPLIB_2018_INCLUDE_DIR             \$INTEL_COMPLIB_2018_Lin_DIR/include            ../../$PACKAGEID/linux/compiler/include;\
-l y  INTEL_COMPLIB_2018_TBB_DIR                 \$INTEL_COMPLIB_2018_Lin_DIR/tbb                ../../$PACKAGEID/linux/tbb;\
-l y  INTEL_COMPLIB_2018_PSTL_DIR                \$INTEL_COMPLIB_2018_Lin_DIR/pstl               ../../$PACKAGEID/linux/pstl;\
-l y  INTEL_COMPLIB_2018_MKL_DIR                 \$INTEL_COMPLIB_2018_Lin_DIR/mkl                ../../$PACKAGEID/linux/mkl;\
-l y  INTEL_COMPLIB_2018_IPP_DIR                 \$INTEL_COMPLIB_2018_Lin_DIR/ipp                ../../$PACKAGEID/linux/ipp;\
-l y  INTEL_COMPLIB_2018_IPPCP_DIR               \$INTEL_COMPLIB_2018_Lin_DIR/ippcp              ../../$PACKAGEID/linux/ippcp;\
-l y  INTEL_COMPLIB_2018_MPIRT_DIR               \$INTEL_COMPLIB_2018_Lin_DIR/mpirt              ../../$PACKAGEID/linux/mpirt;\
-l y  INTEL_COMPLIB_2018_MPI_DIR                 \$INTEL_COMPLIB_2018_Lin_DIR/mpi                ../../$PACKAGEID/linux/mpi;\
-l y  INTEL_COMPLIB_2018_DAAL_DIR                \$INTEL_COMPLIB_2018_Lin_DIR/daal               ../../$PACKAGEID/linux/daal;\
-l y  INTEL_COMPLIB_2018_DEBUGGER_DIR            \$INTEL_COMPLIB_2018_Lin_DIR/debugger           ../../debugger_2018;\
-l n  INTEL_COMPLIB_2018_DOCUMENTATION_DIR       \$INTEL_COMPLIB_2018_Lin_DIR/documentation      ../../documentation_2018;\
-l n  INTEL_COMPLIB_2018_MAN_DIR                 \$INTEL_COMPLIB_2018_Lin_DIR/man                documentation/en/man;\
+d n  INTEL_COMPLIB_2019_DIR                     \$TOP_INTEL_DIR/compilers_and_libraries_2019;\
+d n  INTEL_COMPLIB_2019_Lin_DIR                 \$TOP_INTEL_DIR/compilers_and_libraries_2019/linux;\
+d n  INTEL_COMPLIB_2019_BIN_DIR                 \$INTEL_COMPLIB_2019_Lin_DIR/bin;\
+l n  INTEL_COMPLIB_DIR                          \$TOP_INTEL_DIR/compilers_and_libraries         compilers_and_libraries_2019;\
+l n  INTEL_COMPLIB_2019_PKG_BIN_DIR             \$INTEL_COMPLIB_2019_Lin_DIR/pkg_bin            ../../$PACKAGEID/linux/bin;\
+l n  INTEL_COMPLIB_2019_LIB_DIR                 \$INTEL_COMPLIB_2019_Lin_DIR/lib                ../../$PACKAGEID/linux/compiler/lib;\
+l n  INTEL_COMPLIB_2019_INCLUDE_DIR             \$INTEL_COMPLIB_2019_Lin_DIR/include            ../../$PACKAGEID/linux/compiler/include;\
+l y  INTEL_COMPLIB_2019_TBB_DIR                 \$INTEL_COMPLIB_2019_Lin_DIR/tbb                ../../$PACKAGEID/linux/tbb;\
+l y  INTEL_COMPLIB_2019_PSTL_DIR                \$INTEL_COMPLIB_2019_Lin_DIR/pstl               ../../$PACKAGEID/linux/pstl;\
+l y  INTEL_COMPLIB_2019_MKL_DIR                 \$INTEL_COMPLIB_2019_Lin_DIR/mkl                ../../$PACKAGEID/linux/mkl;\
+l y  INTEL_COMPLIB_2019_IPP_DIR                 \$INTEL_COMPLIB_2019_Lin_DIR/ipp                ../../$PACKAGEID/linux/ipp;\
+l y  INTEL_COMPLIB_2019_IPPCP_DIR               \$INTEL_COMPLIB_2019_Lin_DIR/ippcp              ../../$PACKAGEID/linux/ippcp;\
+l y  INTEL_COMPLIB_2019_MPIRT_DIR               \$INTEL_COMPLIB_2019_Lin_DIR/mpirt              ../../$PACKAGEID/linux/mpirt;\
+l y  INTEL_COMPLIB_2019_MPI_DIR                 \$INTEL_COMPLIB_2019_Lin_DIR/mpi                ../../$PACKAGEID/linux/mpi;\
+l y  INTEL_COMPLIB_2019_DAAL_DIR                \$INTEL_COMPLIB_2019_Lin_DIR/daal               ../../$PACKAGEID/linux/daal;\
+l y  INTEL_COMPLIB_2019_DEBUGGER_DIR            \$INTEL_COMPLIB_2019_Lin_DIR/debugger           ../../debugger_2019;\
+l n  INTEL_COMPLIB_2019_DOCUMENTATION_DIR       \$INTEL_COMPLIB_2019_Lin_DIR/documentation      ../../documentation_2019;\
+l n  INTEL_COMPLIB_2019_MAN_DIR                 \$INTEL_COMPLIB_2019_Lin_DIR/man                documentation/en/man;\
 l n  INTEL_LIB_DIR                              \$TOP_INTEL_DIR/lib                             compilers_and_libraries/linux/lib;\
 l n  INTEL_INCLUDE_DIR                          \$TOP_INTEL_DIR/include                         compilers_and_libraries/linux/include;\
 l n  INTEL_MAN_DIR                              \$TOP_INTEL_DIR/man                             compilers_and_libraries/linux/man;\
@@ -547,8 +547,6 @@ idbc;\
 gcore-ia;\
 gcore-mic;\
 gdb-ia;\
-gdb-mic;\
-gdb-igfx;\
 inspxe-inject;\
 inspxe-runsc;\
 inspxe-wrap"
@@ -777,12 +775,12 @@ OLD_IFS=$IFS
 IFS=";"
 
 # locally hardcoded for test purposes
-#DEFAULT_PACKAGEID="compilers_and_libraries_2018.0.001"
-DEFAULT_PACKAGEID="compilers_and_libraries_2018.3.222"
+#DEFAULT_PACKAGEID="compilers_and_libraries_2019.0.001"
+DEFAULT_PACKAGEID="compilers_and_libraries_2019.1.144"
 
 PACKAGEID=$DEFAULT_PACKAGEID
 
-PACKAGENUM=$(echo $PACKAGEID | sed -e"s/compilers_and_libraries_2018\.[0-9]\.//g")
+PACKAGENUM=$(echo $PACKAGEID | sed -e"s/compilers_and_libraries_2019\.[0-9]\.//g")
     
 # parse script's command line
 PARSE_CMD_ARGS $@
