@@ -310,6 +310,7 @@ void SGEMM(const char *transa, const char *transb, const MKL_INT *m, const MKL_I
            const float *alpha, const float *a, const MKL_INT *lda, const float *b, const MKL_INT *ldb,
            const float *beta, float *c, const MKL_INT *ldc);
 float* SGEMM_ALLOC(const char *identifier, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k);
+MKL_INT SGEMM_PACK_GET_SIZE(const char *identifier, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k);
 void SGEMM_PACK(const char *identifier, const char *trans, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k,
            const float *alpha, const float *src, const MKL_INT *ld, float *dest);
 void SGEMM_COMPUTE(const char *transa, const char *transb, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k,
@@ -401,6 +402,7 @@ void DGEMM(const char *transa, const char *transb, const MKL_INT *m, const MKL_I
            const double *alpha, const double *a, const MKL_INT *lda, const double *b, const MKL_INT *ldb,
            const double *beta, double *c, const MKL_INT *ldc);
 double* DGEMM_ALLOC(const char *identifier, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k);
+MKL_INT DGEMM_PACK_GET_SIZE(const char *identifier, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k);
 void DGEMM_PACK(const char *identifier, const char *trans, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k,
            const double *alpha, const double *src, const MKL_INT *ld, double *dest);
 void DGEMM_COMPUTE(const char *transa, const char *transb, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k,
@@ -497,6 +499,26 @@ void GEMM_S16S16S32(const char *transa, const char *transb, const char *offsetc,
                     const MKL_INT16 *b, const MKL_INT *ldb, const MKL_INT16 *bo,
                     const float *beta, MKL_INT32 *c, const MKL_INT *ldc, const MKL_INT32 *co);
 
+MKL_INT GEMM_S8U8S32_PACK_GET_SIZE   (const char *identifier, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k);
+MKL_INT GEMM_S16S16S32_PACK_GET_SIZE (const char *identifier, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k);
+
+void GEMM_S8U8S32_PACK     (const char *identifier, const char *trans, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k,
+                            const void *src, const MKL_INT *ld, void *dest);
+void GEMM_S16S16S32_PACK   (const char *identifier, const char *trans, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k,
+                            const MKL_INT16 *src, const MKL_INT *ld, MKL_INT16 *dest);
+void GEMM_S8U8S32_COMPUTE  (const char *transa, const char *transb, const char *offsetc,
+                            const MKL_INT *m, const MKL_INT *n, const MKL_INT *k,
+                            const float alpha,
+                            const MKL_INT8  *a, const MKL_INT *lda,  const MKL_INT8 *ao,
+                            const MKL_UINT8 *b, const MKL_INT *ldb,  const MKL_INT8 *bo,
+                            const float *beta, MKL_INT32 *c, const MKL_INT *ldc, const MKL_INT32 *co);
+void GEMM_S16S16S32_COMPUTE(const char *transa, const char *transb, const char *offsetc,
+                            const MKL_INT *m, const MKL_INT *n, const MKL_INT *k,
+                            const float alpha,
+                            const MKL_INT16 *a, const MKL_INT *lda,  const MKL_INT16 *ao,
+                            const MKL_INT16 *b, const MKL_INT *ldb,  const MKL_INT16 *bo,
+                            const float *beta, MKL_INT32 *c, const MKL_INT *ldc, const MKL_INT32 *co);
+
 /* Lower case declaration */
 
 void xerbla(const char *srname, const int *info, const int lsrname);
@@ -779,6 +801,7 @@ void sgemm(const char *transa, const char *transb, const MKL_INT *m, const MKL_I
            const float *alpha, const float *a, const MKL_INT *lda, const float *b, const MKL_INT *ldb,
            const float *beta, float *c, const MKL_INT *ldc);
 float* sgemm_alloc(const char *identifier, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k);
+MKL_INT sgemm_pack_get_size(const char *identifier, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k);
 void sgemm_pack(const char *identifier, const char *trans, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k,
            const float *alpha, const float *src, const MKL_INT *ld, float *dest);
 void sgemm_compute(const char *transa, const char *transb, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k,
@@ -867,6 +890,7 @@ void dgemm(const char *transa, const char *transb, const MKL_INT *m, const MKL_I
            const double *alpha, const double *a, const MKL_INT *lda, const double *b, const MKL_INT *ldb,
            const double *beta, double *c, const MKL_INT *ldc);
 double* dgemm_alloc(const char *identifier, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k);
+MKL_INT dgemm_pack_get_size(const char *identifier, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k);
 void dgemm_pack(const char *identifier, const char *trans, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k,
            const double *alpha, const double *src, const MKL_INT *ld, double *dest);
 void dgemm_compute(const char *transa, const char *transb, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k,
@@ -962,6 +986,50 @@ void gemm_s8u8s32(const char *transa, const char *transb, const char *offsetc,
                     const MKL_UINT8 *b, const MKL_INT *ldb, const MKL_INT8 *bo,
                     const float *beta, MKL_INT32 *c, const MKL_INT *ldc, const MKL_INT32 *co);
 
+MKL_INT gemm_s8u8s32_pack_get_size   (const char *identifier, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k);
+MKL_INT gemm_s16s16s32_pack_get_size (const char *identifier, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k);
+void gemm_s8u8s32_pack     (const char *identifier, const char *trans, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k,
+                            const void *src, const MKL_INT *ld, void *dest);
+void gemm_s16s16s32_pack   (const char *identifier, const char *trans, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k,
+                            const MKL_INT16 *src, const MKL_INT *ld, MKL_INT16 *dest);
+void gemm_s8u8s32_compute  (const char *transa, const char *transb, const char *offsetc,
+                            const MKL_INT *m, const MKL_INT *n, const MKL_INT *k,
+                            const float *alpha,
+                            const MKL_INT8  *a, const MKL_INT *lda,  const MKL_INT8 *ao,
+                            const MKL_UINT8 *b, const MKL_INT *ldb,  const MKL_INT8 *bo,
+                            const float *beta, MKL_INT32 *c, const MKL_INT *ldc, const MKL_INT32 *co);
+void gemm_s16s16s32_compute(const char *transa, const char *transb, const char *offsetc,
+                            const MKL_INT *m, const MKL_INT *n, const MKL_INT *k,
+                            const float *alpha,
+                            const MKL_INT16 *a, const MKL_INT *lda,  const MKL_INT16 *ao,
+                            const MKL_INT16 *b, const MKL_INT *ldb,  const MKL_INT16 *bo,
+                            const float *beta, MKL_INT32 *c, const MKL_INT *ldc, const MKL_INT32 *co);
+
+/*
+ * Jit routines
+ */ 
+#ifndef mkl_jit_create_dgemm
+#define mkl_jit_create_dgemm mkl_cblas_jit_create_dgemm
+#endif
+mkl_jit_status_t mkl_cblas_jit_create_dgemm(void** jitter, const MKL_LAYOUT layout, const MKL_TRANSPOSE transa, const MKL_TRANSPOSE transb,
+                                            const MKL_INT m, const MKL_INT n, const MKL_INT k, 
+                                            const double alpha, const MKL_INT lda, const MKL_INT ldb, 
+                                            const double beta, const MKL_INT ldc);
+
+#ifndef mkl_jit_create_sgemm
+#define mkl_jit_create_sgemm mkl_cblas_jit_create_sgemm
+#endif
+mkl_jit_status_t mkl_cblas_jit_create_sgemm(void** jitter, const MKL_LAYOUT layout, const MKL_TRANSPOSE transa, const MKL_TRANSPOSE transb,
+                                            const MKL_INT m, const MKL_INT n, const MKL_INT k, 
+                                            const float alpha, const MKL_INT lda, const MKL_INT ldb, 
+                                            const float beta, const MKL_INT ldc);
+
+
+dgemm_jit_kernel_t mkl_jit_get_dgemm_ptr(const void* jitter);
+sgemm_jit_kernel_t mkl_jit_get_sgemm_ptr(const void* jitter);
+
+mkl_jit_status_t mkl_jit_destroy(void* jitter);
+
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
