@@ -776,6 +776,8 @@ void cblas_zher2k(const  CBLAS_LAYOUT Layout, const  CBLAS_UPLO Uplo,
  */
 MKL_DECLSPEC float* cblas_sgemm_alloc(const  CBLAS_IDENTIFIER identifier,
                  const MKL_INT M, const MKL_INT N, const MKL_INT K);
+MKL_INT cblas_sgemm_pack_get_size(const  CBLAS_IDENTIFIER identifier,
+                            const MKL_INT M, const MKL_INT N, const MKL_INT K);
 void cblas_sgemm_pack(const  CBLAS_LAYOUT Layout, const  CBLAS_IDENTIFIER identifier,
                  const  CBLAS_TRANSPOSE Trans, const MKL_INT M, const MKL_INT N,
                  const MKL_INT K, const float alpha, const float *src,
@@ -788,6 +790,8 @@ void cblas_sgemm_compute(const  CBLAS_LAYOUT Layout, const MKL_INT TransA,
 void cblas_sgemm_free(float *dest);
 MKL_DECLSPEC double* cblas_dgemm_alloc(const  CBLAS_IDENTIFIER identifier,
                  const MKL_INT M, const MKL_INT N, const MKL_INT K);
+MKL_INT cblas_dgemm_pack_get_size(const  CBLAS_IDENTIFIER identifier,
+                            const MKL_INT M, const MKL_INT N, const MKL_INT K);
 void cblas_dgemm_pack(const  CBLAS_LAYOUT Layout, const  CBLAS_IDENTIFIER identifier,
                  const  CBLAS_TRANSPOSE Trans, const MKL_INT M, const MKL_INT N,
                  const MKL_INT K, const double alpha, const double *src,
@@ -815,6 +819,59 @@ void cblas_gemm_s8u8s32(const CBLAS_LAYOUT Layout, const CBLAS_TRANSPOSE TransA,
                           const void *B, const MKL_INT ldb, const MKL_INT8 bo, const float beta,
                           MKL_INT32 *C, const MKL_INT ldc, const MKL_INT32 *cb);
 
+MKL_INT cblas_gemm_s8u8s32_pack_get_size(const  CBLAS_IDENTIFIER identifier,
+                                   const MKL_INT M, const MKL_INT N, const MKL_INT K);
+MKL_INT cblas_gemm_s16s16s32_pack_get_size(const  CBLAS_IDENTIFIER identifier,
+                                     const MKL_INT M, const MKL_INT N, const MKL_INT K);
+
+void cblas_gemm_s8u8s32_pack  (const  CBLAS_LAYOUT Layout, const  CBLAS_IDENTIFIER identifier,
+                 const  CBLAS_TRANSPOSE Trans, const MKL_INT M, const MKL_INT N, const MKL_INT K,
+                 const void *src, const MKL_INT ld, void *dest);
+void cblas_gemm_s16s16s32_pack(const  CBLAS_LAYOUT Layout, const  CBLAS_IDENTIFIER identifier,
+                 const  CBLAS_TRANSPOSE Trans, const MKL_INT M, const MKL_INT N, const MKL_INT K,
+                 const MKL_INT16 *src, const MKL_INT ld, MKL_INT16 *dest);
+
+void cblas_gemm_s8u8s32_compute  (const  CBLAS_LAYOUT Layout, const CBLAS_TRANSPOSE TransA,
+                 const CBLAS_TRANSPOSE TransB, const CBLAS_OFFSET offsetc,
+                 const MKL_INT M, const MKL_INT N, const MKL_INT K, 
+                 const float alpha,
+                 const void *A, const MKL_INT lda, const MKL_INT8 ao,
+                 const void *B, const MKL_INT ldb, const MKL_INT8 bo,
+                 const float beta,
+                 MKL_INT32 *C, const MKL_INT ldc, const MKL_INT32 *co);
+void cblas_gemm_s16s16s32_compute(const  CBLAS_LAYOUT Layout, const CBLAS_TRANSPOSE TransA,
+                 const CBLAS_TRANSPOSE TransB, const CBLAS_OFFSET offsetc,
+                 const MKL_INT M, const MKL_INT N, const MKL_INT K, 
+                 const float alpha,
+                 const MKL_INT16 *A, const MKL_INT lda, const MKL_INT16 ao,
+                 const MKL_INT16 *B, const MKL_INT ldb, const MKL_INT16 bo,
+                 const float beta,
+                 MKL_INT32 *C, const MKL_INT ldc, const MKL_INT32 *co);
+
+/*
+ * Jit routines
+ */ 
+#ifndef mkl_jit_create_dgemm
+#define mkl_jit_create_dgemm mkl_cblas_jit_create_dgemm
+#endif
+mkl_jit_status_t mkl_cblas_jit_create_dgemm(void** jitter, const MKL_LAYOUT layout, const MKL_TRANSPOSE transa, const MKL_TRANSPOSE transb,
+                                            const MKL_INT m, const MKL_INT n, const MKL_INT k, 
+                                            const double alpha, const MKL_INT lda, const MKL_INT ldb, 
+                                            const double beta, const MKL_INT ldc);
+#ifndef mkl_jit_create_sgemm
+#define mkl_jit_create_sgemm mkl_cblas_jit_create_sgemm
+#endif
+mkl_jit_status_t mkl_cblas_jit_create_sgemm(void** jitter, const MKL_LAYOUT layout, const MKL_TRANSPOSE transa, const MKL_TRANSPOSE transb,
+                                            const MKL_INT m, const MKL_INT n, const MKL_INT k, 
+                                            const float alpha, const MKL_INT lda, const MKL_INT ldb, 
+                                            const float beta, const MKL_INT ldc);
+
+dgemm_jit_kernel_t mkl_jit_get_dgemm_ptr(const void* jitter);
+sgemm_jit_kernel_t mkl_jit_get_sgemm_ptr(const void* jitter);
+
+mkl_jit_status_t mkl_jit_destroy(void* jitter);
+
+
 #ifdef __cplusplus
 }
 #endif    /* __cplusplus */
