@@ -22,7 +22,7 @@
 !*********************************** Basic types and constants *****************
 !*******************************************************************************
 
-    MODULE MKL_SPBLAS
+MODULE MKL_SPBLAS
 
     USE, INTRINSIC :: ISO_C_BINDING , ONLY : C_INTPTR_T, C_INT
 
@@ -447,180 +447,180 @@
 
         FUNCTION MKL_SPARSE_S_EXPORT_BSR(source,indexing,block_layout,rows,cols,block_size,rows_start,rows_end,col_indx,values) &
                  BIND(C, name='MKL_SPARSE_S_EXPORT_BSR')
-            USE, INTRINSIC :: ISO_C_BINDING , ONLY : C_INT, C_FLOAT
+            USE, INTRINSIC :: ISO_C_BINDING , ONLY : C_INT, C_FLOAT, C_PTR
             IMPORT SPARSE_MATRIX_T
             TYPE(SPARSE_MATRIX_T), INTENT(IN) :: source
-            INTEGER(C_INT)       , INTENT(INOUT) :: indexing
-            INTEGER(C_INT)       , INTENT(INOUT) :: block_layout
-            INTEGER(C_INT)       , INTENT(INOUT) :: rows
-            INTEGER(C_INT)       , INTENT(INOUT) :: cols
-            INTEGER(C_INT)       , INTENT(INOUT) :: block_size
-            INTEGER, INTENT(INOUT), DIMENSION(*) :: rows_start
-            INTEGER, INTENT(INOUT), DIMENSION(*) :: rows_end
-            INTEGER, INTENT(INOUT), DIMENSION(*) :: col_indx
-            REAL(C_FLOAT), INTENT(INOUT), DIMENSION(*) :: values
+            INTEGER(C_INT), INTENT(INOUT) :: indexing
+            INTEGER(C_INT), INTENT(INOUT) :: block_layout
+            INTEGER       , INTENT(INOUT) :: rows
+            INTEGER       , INTENT(INOUT) :: cols
+            INTEGER       , INTENT(INOUT) :: block_size
+            TYPE(C_PTR)   , INTENT(INOUT) :: rows_start
+            TYPE(C_PTR)   , INTENT(INOUT) :: rows_end
+            TYPE(C_PTR)   , INTENT(INOUT) :: col_indx
+            TYPE(C_PTR)   , INTENT(INOUT) :: values
             INTEGER(C_INT) MKL_SPARSE_S_EXPORT_BSR
         END FUNCTION
         FUNCTION MKL_SPARSE_D_EXPORT_BSR(source,indexing,block_layout,rows,cols,block_size,rows_start,rows_end,col_indx,values) &
                  BIND(C, name='MKL_SPARSE_D_EXPORT_BSR')
-            USE, INTRINSIC :: ISO_C_BINDING , ONLY : C_INT, C_DOUBLE
+            USE, INTRINSIC :: ISO_C_BINDING , ONLY : C_INT, C_DOUBLE, C_PTR
             IMPORT SPARSE_MATRIX_T
             TYPE(SPARSE_MATRIX_T) , INTENT(IN) :: source
-            INTEGER(C_INT)        , INTENT(INOUT) :: indexing
-            INTEGER(C_INT)        , INTENT(INOUT) :: block_layout
-            INTEGER(C_INT)        , INTENT(INOUT) :: rows
-            INTEGER(C_INT)        , INTENT(INOUT) :: cols
-            INTEGER(C_INT)        , INTENT(INOUT) :: block_size
-            INTEGER, INTENT(INOUT), DIMENSION(*) :: rows_start
-            INTEGER, INTENT(INOUT), DIMENSION(*) :: rows_end
-            INTEGER, INTENT(INOUT), DIMENSION(*) :: col_indx
-            REAL(C_DOUBLE), INTENT(INOUT), DIMENSION(*) :: values
+            INTEGER(C_INT), INTENT(INOUT) :: indexing
+            INTEGER(C_INT), INTENT(INOUT) :: block_layout
+            INTEGER       , INTENT(INOUT) :: rows
+            INTEGER       , INTENT(INOUT) :: cols
+            INTEGER       , INTENT(INOUT) :: block_size
+            TYPE(C_PTR)   , INTENT(INOUT) :: rows_start
+            TYPE(C_PTR)   , INTENT(INOUT) :: rows_end
+            TYPE(C_PTR)   , INTENT(INOUT) :: col_indx
+            TYPE(C_PTR)   , INTENT(INOUT) :: values
             INTEGER(C_INT) MKL_SPARSE_D_EXPORT_BSR
         END FUNCTION
         FUNCTION MKL_SPARSE_C_EXPORT_BSR(source,indexing,block_layout,rows,cols,block_size,rows_start,rows_end,col_indx,values) &
                  BIND(C, name='MKL_SPARSE_C_EXPORT_BSR')
-            USE, INTRINSIC :: ISO_C_BINDING , ONLY : C_INT, C_FLOAT_COMPLEX
+            USE, INTRINSIC :: ISO_C_BINDING , ONLY : C_INT, C_FLOAT_COMPLEX, C_PTR
             IMPORT SPARSE_MATRIX_T
             TYPE(SPARSE_MATRIX_T) , INTENT(IN) :: source
-            INTEGER(C_INT)        , INTENT(INOUT) :: indexing
-            INTEGER(C_INT)        , INTENT(INOUT) :: block_layout
-            INTEGER(C_INT)        , INTENT(INOUT) :: rows
-            INTEGER(C_INT)        , INTENT(INOUT) :: cols
-            INTEGER(C_INT)        , INTENT(INOUT) :: block_size
-            INTEGER, INTENT(INOUT), DIMENSION(*) :: rows_start
-            INTEGER, INTENT(INOUT), DIMENSION(*) :: rows_end
-            INTEGER, INTENT(INOUT), DIMENSION(*) :: col_indx
-            COMPLEX(C_FLOAT_COMPLEX), INTENT(INOUT), DIMENSION(*) :: values
+            INTEGER(C_INT), INTENT(INOUT) :: indexing
+            INTEGER(C_INT), INTENT(INOUT) :: block_layout
+            INTEGER       , INTENT(INOUT) :: rows
+            INTEGER       , INTENT(INOUT) :: cols
+            INTEGER       , INTENT(INOUT) :: block_size
+            TYPE(C_PTR)   , INTENT(INOUT) :: rows_start
+            TYPE(C_PTR)   , INTENT(INOUT) :: rows_end
+            TYPE(C_PTR)   , INTENT(INOUT) :: col_indx
+            TYPE(C_PTR)   , INTENT(INOUT) :: values
             INTEGER(C_INT) MKL_SPARSE_C_EXPORT_BSR
         END FUNCTION
         FUNCTION MKL_SPARSE_Z_EXPORT_BSR(source,indexing,block_layout,rows,cols,block_size,rows_start,rows_end,col_indx,values) &
                  BIND(C, name='MKL_SPARSE_Z_EXPORT_BSR')
-            USE, INTRINSIC :: ISO_C_BINDING , ONLY : C_INT, C_DOUBLE_COMPLEX
+            USE, INTRINSIC :: ISO_C_BINDING , ONLY : C_INT, C_DOUBLE_COMPLEX, C_PTR
             IMPORT SPARSE_MATRIX_T
             TYPE(SPARSE_MATRIX_T) , INTENT(IN) :: source
-            INTEGER(C_INT)        , INTENT(INOUT) :: indexing
-            INTEGER(C_INT)        , INTENT(INOUT) :: block_layout
-            INTEGER(C_INT)        , INTENT(INOUT) :: rows
-            INTEGER(C_INT)        , INTENT(INOUT) :: cols
-            INTEGER(C_INT)        , INTENT(INOUT) :: block_size
-            INTEGER, INTENT(INOUT), DIMENSION(*) :: rows_start
-            INTEGER, INTENT(INOUT), DIMENSION(*) :: rows_end
-            INTEGER, INTENT(INOUT), DIMENSION(*) :: col_indx
-            COMPLEX(C_DOUBLE_COMPLEX), INTENT(INOUT), DIMENSION(*) :: values
+            INTEGER(C_INT), INTENT(INOUT) :: indexing
+            INTEGER(C_INT), INTENT(INOUT) :: block_layout
+            INTEGER       , INTENT(INOUT) :: rows
+            INTEGER       , INTENT(INOUT) :: cols
+            INTEGER       , INTENT(INOUT) :: block_size
+            TYPE(C_PTR)   , INTENT(INOUT) :: rows_start
+            TYPE(C_PTR)   , INTENT(INOUT) :: rows_end
+            TYPE(C_PTR)   , INTENT(INOUT) :: col_indx
+            TYPE(C_PTR)   , INTENT(INOUT) :: values
             INTEGER(C_INT) MKL_SPARSE_Z_EXPORT_BSR
         END FUNCTION
 
         FUNCTION MKL_SPARSE_S_EXPORT_CSR(source,indexing,rows,cols,rows_start,rows_end,col_indx,values) &
                  BIND(C, name='MKL_SPARSE_S_EXPORT_CSR')
-            USE, INTRINSIC :: ISO_C_BINDING , ONLY : C_INT, C_FLOAT
+            USE, INTRINSIC :: ISO_C_BINDING , ONLY : C_INT, C_FLOAT, C_PTR
             IMPORT SPARSE_MATRIX_T
             TYPE(SPARSE_MATRIX_T), INTENT(IN) :: source
-            INTEGER(C_INT)      , INTENT(INOUT) :: indexing
-            INTEGER(C_INT)      , INTENT(INOUT) :: rows
-            INTEGER(C_INT)      , INTENT(INOUT) :: cols
-            INTEGER, INTENT(INOUT), DIMENSION(*) :: rows_start
-            INTEGER, INTENT(INOUT), DIMENSION(*) :: rows_end
-            INTEGER, INTENT(INOUT), DIMENSION(*) :: col_indx
-            REAL(C_FLOAT), INTENT(INOUT), DIMENSION(*) :: values
+            INTEGER(C_INT), INTENT(INOUT) :: indexing
+            INTEGER       , INTENT(INOUT) :: rows
+            INTEGER       , INTENT(INOUT) :: cols
+            TYPE(C_PTR)   , INTENT(INOUT) :: rows_start
+            TYPE(C_PTR)   , INTENT(INOUT) :: rows_end
+            TYPE(C_PTR)   , INTENT(INOUT) :: col_indx
+            TYPE(C_PTR)   , INTENT(INOUT) :: values
             INTEGER(C_INT) MKL_SPARSE_S_EXPORT_CSR
         END FUNCTION
         FUNCTION MKL_SPARSE_D_EXPORT_CSR(source,indexing,rows,cols,rows_start,rows_end,col_indx,values) &
                  BIND(C, name='MKL_SPARSE_D_EXPORT_CSR')
-            USE, INTRINSIC :: ISO_C_BINDING , ONLY : C_INT, C_DOUBLE
+            USE, INTRINSIC :: ISO_C_BINDING , ONLY : C_INT, C_DOUBLE, C_PTR
             IMPORT SPARSE_MATRIX_T
             TYPE(SPARSE_MATRIX_T), INTENT(IN) :: source
-            INTEGER(C_INT)      , INTENT(INOUT) :: indexing
-            INTEGER(C_INT)      , INTENT(INOUT) :: rows
-            INTEGER(C_INT)      , INTENT(INOUT) :: cols
-            INTEGER, INTENT(INOUT), DIMENSION(*) :: rows_start
-            INTEGER, INTENT(INOUT), DIMENSION(*) :: rows_end
-            INTEGER, INTENT(INOUT), DIMENSION(*) :: col_indx
-            REAL(C_DOUBLE), INTENT(INOUT), DIMENSION(*) :: values
+            INTEGER(C_INT), INTENT(INOUT) :: indexing
+            INTEGER       , INTENT(INOUT) :: rows
+            INTEGER       , INTENT(INOUT) :: cols
+            TYPE(C_PTR)   , INTENT(INOUT) :: rows_start
+            TYPE(C_PTR)   , INTENT(INOUT) :: rows_end
+            TYPE(C_PTR)   , INTENT(INOUT) :: col_indx
+            TYPE(C_PTR)   , INTENT(INOUT) :: values
             INTEGER(C_INT) MKL_SPARSE_D_EXPORT_CSR
         END FUNCTION
         FUNCTION MKL_SPARSE_C_EXPORT_CSR(source,indexing,rows,cols,rows_start,rows_end,col_indx,values) &
                  BIND(C, name='MKL_SPARSE_C_EXPORT_CSR')
-            USE, INTRINSIC :: ISO_C_BINDING , ONLY : C_INT, C_FLOAT_COMPLEX
+            USE, INTRINSIC :: ISO_C_BINDING , ONLY : C_INT, C_FLOAT_COMPLEX, C_PTR
             IMPORT SPARSE_MATRIX_T
             TYPE(SPARSE_MATRIX_T), INTENT(IN) :: source
-            INTEGER(C_INT)      , INTENT(INOUT) :: indexing
-            INTEGER(C_INT)      , INTENT(INOUT) :: rows
-            INTEGER(C_INT)      , INTENT(INOUT) :: cols
-            INTEGER, INTENT(INOUT), DIMENSION(*) :: rows_start
-            INTEGER, INTENT(INOUT), DIMENSION(*) :: rows_end
-            INTEGER, INTENT(INOUT), DIMENSION(*) :: col_indx
-            COMPLEX(C_FLOAT_COMPLEX), INTENT(INOUT), DIMENSION(*) :: values
+            INTEGER(C_INT), INTENT(INOUT) :: indexing
+            INTEGER       , INTENT(INOUT) :: rows
+            INTEGER       , INTENT(INOUT) :: cols
+            TYPE(C_PTR)   , INTENT(INOUT) :: rows_start
+            TYPE(C_PTR)   , INTENT(INOUT) :: rows_end
+            TYPE(C_PTR)   , INTENT(INOUT) :: col_indx
+            TYPE(C_PTR)   , INTENT(INOUT) :: values
             INTEGER(C_INT) MKL_SPARSE_C_EXPORT_CSR
         END FUNCTION
         FUNCTION MKL_SPARSE_Z_EXPORT_CSR(source,indexing,rows,cols,rows_start,rows_end,col_indx,values) &
                  BIND(C, name='MKL_SPARSE_Z_EXPORT_CSR')
-            USE, INTRINSIC :: ISO_C_BINDING , ONLY : C_INT, C_DOUBLE_COMPLEX
+            USE, INTRINSIC :: ISO_C_BINDING , ONLY : C_INT, C_DOUBLE_COMPLEX, C_PTR
             IMPORT SPARSE_MATRIX_T
             TYPE(SPARSE_MATRIX_T) , INTENT(IN) :: source
-            INTEGER(C_INT)        , INTENT(INOUT) :: indexing
-            INTEGER(C_INT)        , INTENT(INOUT) :: rows
-            INTEGER(C_INT)        , INTENT(INOUT) :: cols
-            INTEGER, INTENT(INOUT), DIMENSION(*) :: rows_start
-            INTEGER, INTENT(INOUT), DIMENSION(*) :: rows_end
-            INTEGER, INTENT(INOUT), DIMENSION(*) :: col_indx
-            COMPLEX(C_DOUBLE_COMPLEX), INTENT(INOUT), DIMENSION(*) :: values
+            INTEGER(C_INT), INTENT(INOUT) :: indexing
+            INTEGER       , INTENT(INOUT) :: rows
+            INTEGER       , INTENT(INOUT) :: cols
+            TYPE(C_PTR)   , INTENT(INOUT) :: rows_start
+            TYPE(C_PTR)   , INTENT(INOUT) :: rows_end
+            TYPE(C_PTR)   , INTENT(INOUT) :: col_indx
+            TYPE(C_PTR)   , INTENT(INOUT) :: values
             INTEGER(C_INT) MKL_SPARSE_Z_EXPORT_CSR
         END FUNCTION
 
         FUNCTION MKL_SPARSE_S_EXPORT_CSC(source,indexing,rows,cols,rows_start,rows_end,col_indx,values) &
                  BIND(C, name='MKL_SPARSE_S_EXPORT_CSC')
-            USE, INTRINSIC :: ISO_C_BINDING , ONLY : C_INT, C_FLOAT
+            USE, INTRINSIC :: ISO_C_BINDING , ONLY : C_INT, C_FLOAT, C_PTR
             IMPORT SPARSE_MATRIX_T
             TYPE(SPARSE_MATRIX_T), INTENT(IN) :: source
-            INTEGER(C_INT)      , INTENT(INOUT) :: indexing
-            INTEGER(C_INT)      , INTENT(INOUT) :: rows
-            INTEGER(C_INT)      , INTENT(INOUT) :: cols
-            INTEGER, INTENT(INOUT), DIMENSION(*) :: rows_start
-            INTEGER, INTENT(INOUT), DIMENSION(*) :: rows_end
-            INTEGER, INTENT(INOUT), DIMENSION(*) :: col_indx
-            REAL(C_FLOAT), INTENT(INOUT), DIMENSION(*) :: values
+            INTEGER(C_INT), INTENT(INOUT) :: indexing
+            INTEGER       , INTENT(INOUT) :: rows
+            INTEGER       , INTENT(INOUT) :: cols
+            TYPE(C_PTR)   , INTENT(INOUT) :: rows_start
+            TYPE(C_PTR)   , INTENT(INOUT) :: rows_end
+            TYPE(C_PTR)   , INTENT(INOUT) :: col_indx
+            TYPE(C_PTR)   , INTENT(INOUT) :: values
             INTEGER(C_INT) MKL_SPARSE_S_EXPORT_CSC
         END FUNCTION
         FUNCTION MKL_SPARSE_D_EXPORT_CSC(source,indexing,rows,cols,rows_start,rows_end,col_indx,values) &
                  BIND(C, name='MKL_SPARSE_D_EXPORT_CSC')
-            USE, INTRINSIC :: ISO_C_BINDING , ONLY : C_INT, C_DOUBLE
+            USE, INTRINSIC :: ISO_C_BINDING , ONLY : C_INT, C_DOUBLE, C_PTR
             IMPORT SPARSE_MATRIX_T
             TYPE(SPARSE_MATRIX_T), INTENT(IN) :: source
-            INTEGER(C_INT)      , INTENT(INOUT) :: indexing
-            INTEGER(C_INT)      , INTENT(INOUT) :: rows
-            INTEGER(C_INT)      , INTENT(INOUT) :: cols
-            INTEGER, INTENT(INOUT), DIMENSION(*) :: rows_start
-            INTEGER, INTENT(INOUT), DIMENSION(*) :: rows_end
-            INTEGER, INTENT(INOUT), DIMENSION(*) :: col_indx
-            REAL(C_DOUBLE), INTENT(INOUT), DIMENSION(*) :: values
+            INTEGER(C_INT), INTENT(INOUT) :: indexing
+            INTEGER       , INTENT(INOUT) :: rows
+            INTEGER       , INTENT(INOUT) :: cols
+            TYPE(C_PTR)   , INTENT(INOUT) :: rows_start
+            TYPE(C_PTR)   , INTENT(INOUT) :: rows_end
+            TYPE(C_PTR)   , INTENT(INOUT) :: col_indx
+            TYPE(C_PTR)   , INTENT(INOUT) :: values
             INTEGER(C_INT) MKL_SPARSE_D_EXPORT_CSC
         END FUNCTION
         FUNCTION MKL_SPARSE_C_EXPORT_CSC(source,indexing,rows,cols,rows_start,rows_end,col_indx,values) &
                  BIND(C, name='MKL_SPARSE_C_EXPORT_CSC')
-            USE, INTRINSIC :: ISO_C_BINDING , ONLY : C_INT, C_FLOAT_COMPLEX
+            USE, INTRINSIC :: ISO_C_BINDING , ONLY : C_INT, C_FLOAT_COMPLEX, C_PTR
             IMPORT SPARSE_MATRIX_T
             TYPE(SPARSE_MATRIX_T), INTENT(IN) :: source
-            INTEGER(C_INT)      , INTENT(INOUT) :: indexing
-            INTEGER(C_INT)      , INTENT(INOUT) :: rows
-            INTEGER(C_INT)      , INTENT(INOUT) :: cols
-            INTEGER, INTENT(INOUT), DIMENSION(*) :: rows_start
-            INTEGER, INTENT(INOUT), DIMENSION(*) :: rows_end
-            INTEGER, INTENT(INOUT), DIMENSION(*) :: col_indx
-            COMPLEX(C_FLOAT_COMPLEX), INTENT(INOUT), DIMENSION(*) :: values
+            INTEGER(C_INT), INTENT(INOUT) :: indexing
+            INTEGER       , INTENT(INOUT) :: rows
+            INTEGER       , INTENT(INOUT) :: cols
+            TYPE(C_PTR)   , INTENT(INOUT) :: rows_start
+            TYPE(C_PTR)   , INTENT(INOUT) :: rows_end
+            TYPE(C_PTR)   , INTENT(INOUT) :: col_indx
+            TYPE(C_PTR)   , INTENT(INOUT) :: values
             INTEGER(C_INT) MKL_SPARSE_C_EXPORT_CSC
         END FUNCTION
         FUNCTION MKL_SPARSE_Z_EXPORT_CSC(source,indexing,rows,cols,rows_start,rows_end,col_indx,values) &
                  BIND(C, name='MKL_SPARSE_Z_EXPORT_CSC')
-            USE, INTRINSIC :: ISO_C_BINDING , ONLY : C_INT, C_DOUBLE_COMPLEX
+            USE, INTRINSIC :: ISO_C_BINDING , ONLY : C_INT, C_DOUBLE_COMPLEX, C_PTR
             IMPORT SPARSE_MATRIX_T
             TYPE(SPARSE_MATRIX_T) , INTENT(IN) :: source
-            INTEGER(C_INT)        , INTENT(INOUT) :: indexing
-            INTEGER(C_INT)        , INTENT(INOUT) :: rows
-            INTEGER(C_INT)        , INTENT(INOUT) :: cols
-            INTEGER, INTENT(INOUT), DIMENSION(*) :: rows_start
-            INTEGER, INTENT(INOUT), DIMENSION(*) :: rows_end
-            INTEGER, INTENT(INOUT), DIMENSION(*) :: col_indx
-            COMPLEX(C_DOUBLE_COMPLEX), INTENT(INOUT), DIMENSION(*) :: values
+            INTEGER(C_INT), INTENT(INOUT) :: indexing
+            INTEGER       , INTENT(INOUT) :: rows
+            INTEGER       , INTENT(INOUT) :: cols
+            TYPE(C_PTR)   , INTENT(INOUT) :: rows_start
+            TYPE(C_PTR)   , INTENT(INOUT) :: rows_end
+            TYPE(C_PTR)   , INTENT(INOUT) :: col_indx
+            TYPE(C_PTR)   , INTENT(INOUT) :: values
             INTEGER(C_INT) MKL_SPARSE_Z_EXPORT_CSC
         END FUNCTION
 
@@ -1166,12 +1166,12 @@
             IMPORT SPARSE_MATRIX_T
             INTEGER(C_INT)              , INTENT(IN)   :: op
             TYPE(SPARSE_MATRIX_T)       , INTENT(IN)   :: A
-            REAL(C_FLOAT_COMPLEX)       , INTENT(IN) , DIMENSION(*) :: B
+            COMPLEX(C_FLOAT_COMPLEX)    , INTENT(IN) , DIMENSION(*) :: B
             INTEGER(C_INT)              , INTENT(IN)   :: layoutB
             INTEGER(C_INT)              , INTENT(IN)   :: ldb
-            REAL(C_FLOAT_COMPLEX)       , INTENT(IN)   :: alpha
-            REAL(C_FLOAT_COMPLEX)       , INTENT(IN)   :: beta
-            REAL(C_FLOAT_COMPLEX)       , INTENT(OUT), DIMENSION(*) :: C
+            COMPLEX(C_FLOAT_COMPLEX)    , INTENT(IN)   :: alpha
+            COMPLEX(C_FLOAT_COMPLEX)    , INTENT(IN)   :: beta
+            COMPLEX(C_FLOAT_COMPLEX)    , INTENT(OUT), DIMENSION(*) :: C
             INTEGER(C_INT)              , INTENT(IN)   :: layoutC
             INTEGER(C_INT)              , INTENT(IN)   :: ldc
             INTEGER(C_INT) MKL_SPARSE_C_SYPRD
@@ -1182,12 +1182,12 @@
             IMPORT SPARSE_MATRIX_T
             INTEGER(C_INT)              , INTENT(IN)   :: op
             TYPE(SPARSE_MATRIX_T)       , INTENT(IN)   :: A
-            REAL(C_DOUBLE_COMPLEX)      , INTENT(IN) , DIMENSION(*) :: B
+            COMPLEX(C_DOUBLE_COMPLEX)   , INTENT(IN) , DIMENSION(*) :: B
             INTEGER(C_INT)              , INTENT(IN)   :: layoutB
             INTEGER(C_INT)              , INTENT(IN)   :: ldb
-            REAL(C_DOUBLE_COMPLEX)      , INTENT(IN)   :: alpha
-            REAL(C_DOUBLE_COMPLEX)      , INTENT(IN)   :: beta
-            REAL(C_DOUBLE_COMPLEX)      , INTENT(OUT), DIMENSION(*) :: C
+            COMPLEX(C_DOUBLE_COMPLEX)   , INTENT(IN)   :: alpha
+            COMPLEX(C_DOUBLE_COMPLEX)   , INTENT(IN)   :: beta
+            COMPLEX(C_DOUBLE_COMPLEX)   , INTENT(OUT), DIMENSION(*) :: C
             INTEGER(C_INT)              , INTENT(IN)   :: layoutC
             INTEGER(C_INT)              , INTENT(IN)   :: ldc
             INTEGER(C_INT) MKL_SPARSE_Z_SYPRD
@@ -1576,4 +1576,4 @@
 
     END INTERFACE
 
-    END MODULE MKL_SPBLAS
+END MODULE MKL_SPBLAS
