@@ -74,6 +74,9 @@ extern "C" {
 /* ARS5 stream related errors */
 #define VSL_RNG_ERROR_ARS5_NOT_SUPPORTED        -1140
 
+/* Multinomial distribution probability array related errors */
+#define VSL_DISTR_MULTINOMIAL_BAD_PROBABILITY_ARRAY    -1150
+
 /* read/write stream to file errors */
 #define VSL_RNG_ERROR_FILE_CLOSE                -1100
 #define VSL_RNG_ERROR_FILE_OPEN                 -1101
@@ -690,6 +693,14 @@ extern "C" {
 */
 #define VSL_RNG_METHOD_BINOMIAL_BTPE 0 /* vsliRngBinomial */
 
+/*
+// Multinomial
+//
+// <Method>    <Short Description>
+// MULTPOISSON Poisson Approximation of Multinomial Distribution method
+*/
+#define VSL_RNG_METHOD_MULTINOMIAL_MULTPOISSON 0 /* vsliRngMultinomial */
+
 /*
 // Hypergeometric
 //
