@@ -250,139 +250,6 @@ get_strings()
     fi
 }
 
-privileges_ask_root()
-{
-    echo "$LI_bash_log_as_root"
-    rm -rf $temp_folder >/dev/null 2>&1
-    sh -c "(exec su - root -c \"sh \\\"$fullpath/$thisexec\\\" $cli_mode_params $params || true\")"
-    if [ "$?" = "0" ]; then
-        exit $EXIT_CODE_SUCCESS
-    else 
-        echo -n "$LI_bash_log_as_root_failed"
-        read usr_choice >/dev/null 2>&1
-        if [ "$usr_choice" = "y" ] || [ -z "$usr_choice" ]; then 
-            REPEAT_LOOP=1
-        else
-            echo "$LI_bash_quit"
-            exit $EXIT_CODE_SUCCESS
-        fi    
-    fi
-}
-
-privileges_ask_sudo()
-{
-    echo "$LI_bash_log_as_sudo"
-    rm -rf $temp_folder >/dev/null 2>&1
-    sh -c "(sudo su - root -c \"sh \\\"$fullpath/$thisexec\\\" $cli_mode_params $params || true\")"
-    if [ "$?" = $EXIT_CODE_SUCCESS ]; then
-        exit $EXIT_CODE_SUCCESS
-    else
-        echo -n "$LI_bash_log_as_sudo_failed"
-        read usr_choice >/dev/null 2>&1
-        if [ "$usr_choice" = "y" ] || [ -z "$usr_choice" ]; then 
-            REPEAT_LOOP=1
-        else
-            echo "$LI_bash_quit"
-            exit $EXIT_CODE_SUCCESS
-        fi    
-    fi
-}
-
-privileges_ask_user()
-{
-    echo "$LI_bash_log_as_user"
-    REPEAT_LOOP=0
-}
-
-generate_n_display_dialog()
-{
-    root_nonroot_help="$LI_bash_log_root_nonroot_help_header"
-    local idx=0
-    echo "$LI_bash_root_nonroot_header"
-    echo ""
-    if [ $PRIVILEGE_MODE_ROOT -eq 1 ]; then
-        idx=$((idx + 1))
-        echo "${idx}. $LI_bash_run_as_root"
-        root_nonroot_help="$root_nonroot_help \
-
--- $LI_bash_option ${idx} -- \
-$LI_bash_log_root_nonroot_help_option_root"
-    fi
-    if [ $PRIVILEGE_MODE_SUDO -eq 1 ]; then
-        idx=$((idx + 1))
-        echo "${idx}. $LI_bash_run_as_sudo"
-        root_nonroot_help="$root_nonroot_help \
-
--- $LI_bash_option ${idx} -- \
-$LI_bash_log_root_nonroot_help_option_sudo"
-    fi
-    if [ $PRIVILEGE_MODE_USER -eq 1 ]; then
-        idx=$((idx + 1))
-        echo "${idx}. $LI_bash_run_as_user"
-        root_nonroot_help="$root_nonroot_help \
-
--- $LI_bash_option ${idx} -- \
-$LI_bash_log_root_nonroot_help_option_user"
-    fi
-    root_nonroot_help="$root_nonroot_help \
-
-$LI_bash_log_root_nonroot_help_footer"
-
-    echo "$LI_bash_root_nonroot_footer"
-    echo " "
-    echo -n "$LI_bash_root_nonroot_question"
-}
-
-cli_root_nonroot_dialog()
-{
-    REPEAT_LOOP=1
-
-    PRIVILEGE_MODE_ROOT=1
-    PRIVILEGE_MODE_SUDO=1
-    PRIVILEGE_MODE_USER=1
-    [ "$pset_mode" = "uninstall" ] && PRIVILEGE_MODE_USER=0
-    ! is_sudo_available && PRIVILEGE_MODE_SUDO=0
-
-    while [ "$REPEAT_LOOP" = 1 ]; do
-        generate_n_display_dialog
-        read  usr_choice >/dev/null 2>&1
-        if [ -z "$usr_choice" ]; then
-            usr_choice=1
-        fi
-        case $usr_choice in
-        1 )
-            privileges_ask_root
-            ;;
-        2 )
-            if [ $PRIVILEGE_MODE_SUDO -eq 1 ]; then
-                privileges_ask_sudo
-            elif [ $PRIVILEGE_MODE_USER -eq 1 ]; then
-                privileges_ask_user
-            fi
-            ;;
-        3 )
-            if [ $PRIVILEGE_MODE_USER -eq 1 ] && [ $PRIVILEGE_MODE_SUDO -eq 1 ]; then
-                privileges_ask_user
-            fi
-            ;;
-        h )
-            echo "$root_nonroot_help"
-            echo -n "$LI_to_continue_question"
-            read  dummy >/dev/null 2>&1
-            ;;
-        q )
-            echo "$LI_bash_log_quit"
-            rm -rf $temp_dir >/dev/null 2>&1
-            exit 4
-            ;;
-
-        * ) echo "$LI_bash_log_invalid_choice"
-            REPEAT_LOOP=1 
-            ;;
-        esac
-    done
-}
-
 check_cli_binary()
 {
     if [ ! -f "$pset_engine_cli_binary" ]; then
@@ -396,13 +263,13 @@ check_cli_binary()
 
 add_root_to_xhost_acl()
 {
-    if [ "$USER" != "$(whoami)" ] && [ "$(whoami)" = "root" ]; then 
-        if [ -z "$(su $USER -c xhost | grep -i 'si:localuser:root')" ]; then
+    if [ "$USER" != "$(whoami)" ] && [ "$(whoami)" = "root" ]; then
+        if [ -z "$(su $USER -c xhost 2>&1 | grep -i 'si:localuser:root')" ]; then
             su $USER -c 'xhost +si:localuser:root' > /dev/null 2>&1
             root_added_to_xhost_acl="yes"
         fi
     else
-        if [ -z "$(xhost | grep -i 'si:localuser:root')" ]; then
+        if [ -z "$(xhost 2>&1 | grep -i 'si:localuser:root')" ]; then
             xhost +si:localuser:root > /dev/null 2>&1
             root_added_to_xhost_acl="yes"
         fi
@@ -411,19 +278,32 @@ add_root_to_xhost_acl()
 
 remove_root_from_xhost_acl()
 {
-    if [ "$USER" != "$(whoami)" ] && [ "$(whoami)" = "root" ]; then 
+    if [ "$USER" != "$(whoami)" ] && [ "$(whoami)" = "root" ]; then
         su $USER -c 'LD_LIBRARY_PATH=""; xhost -si:localuser:root' > /dev/null 2>&1
     else
         LD_LIBRARY_PATH=""; xhost -si:localuser:root > /dev/null 2>&1
     fi
 }
 
+check_display()
+{
+    if [ "$(uname)" = "Darwin" ]; then
+        if [[ -z $(system_profiler SPDisplaysDataType | grep Display:) ]]; then
+            echo "\n############################################"
+            echo " Can not detect display"
+            echo " Installer may work incorrectly in GUI mode"
+            echo "############################################\n"
+        fi
+    fi
+}
+
+
 # script start
 thisexec=`basename "$0"`
 thisdir=`dirname "$0"`
 [ -z "$HOSTNAME" ] && HOSTNAME=$(hostname);
 skip_gui_install="yes"
-suite_guid="1526383007007"
+suite_guid="1540897558659"
 root_added_to_xhost_acl="no"
 
 trap "" TSTP # Disable Ctrl-Z
@@ -485,14 +365,23 @@ if [ "$skip_cpu_check" != "yes" ]; then
 fi
 
 #to start GUI with root privileges on Wayland (Fedora 25)
-if [ "$(uname)" != "Darwin" ] && [ "yes" != "${skip_gui_install}" ] && [ "$XDG_SESSION_TYPE" = "wayland" ]; then
+if [ "$(uname)" != "Darwin" ] && [ "yes" != "${skip_gui_install}" ]; then
     add_root_to_xhost_acl
 fi
 
 #define and check temporary dir
 if [ -z "$user_tmp" ]; then
-    if [ -z "$TMPDIR" ]; then    
-        user_tmp="/tmp"
+    if [ -z "$TMPDIR" ]; then
+        if [ "$(uname)" = "Darwin" ]; then
+            temp_folder=$(mktemp -dt "install" 2>/dev/null)
+            export TMPDIR=`dirname $temp_folder`
+            user_tmp=$TMPDIR
+        else
+            user_tmp="/tmp"
+            if [ "$(df -P ${user_tmp} | tail -n1 | cut -d' ' -f1)" = "tmpfs" ]; then
+                user_tmp="/var/tmp"
+            fi
+        fi
     else
         if [ -d "$TMPDIR" ]; then
             user_tmp=$TMPDIR
@@ -506,15 +395,7 @@ if ! echo "$user_tmp" | grep -q -s ^/ && ! echo "$user_tmp" | grep -q -s ^~ ; th
    user_tmp="`pwd`/$user_tmp"
 fi
 
-[ -z "${check_only}" ] && temp_folder=$(mktemp -d "$user_tmp/install.XXXXXX" 2>/dev/null)
-
-if [ -z "$download_tmp" ]; then
-    if [ "$(uname)" = "Darwin" ]; then
-        download_tmp=$HOME/Downloads
-    else
-        download_tmp=$user_tmp
-    fi
-fi
+[ -z "${check_only}" ] && [ -z "${temp_folder}" ] && temp_folder=$(mktemp -d "$user_tmp/install.XXXXXX" 2>/dev/null)
 
 params="$params --PRODUCT_ID \"$PRODUCT_ID\""
 
@@ -588,6 +469,9 @@ fi
 #if yes, no root-nonroot dialog will be shown
 [ $UID -eq 0 ] && skip_uid_check=yes
 
+#init variable
+show_sudo_dialog=0
+
 if [ "$pset_mode" = "uninstall" ]; then
     show_sudo_dialog=0
     settings_file=""
@@ -628,14 +512,7 @@ if [ "$pset_mode" = "uninstall" ]; then
         [ $UID -ne 0 ] && show_sudo_dialog=1
     fi
 else
-    show_sudo_dialog=1
-fi
-
-# if we still here, check again
-if [ $show_sudo_dialog -eq 1 ] && ! can_escalate_privileges; then
-    # It's not possible to escalate priviledges as current user does not belong to 'wheel' group.
-    # Continuing with current user privileges
-    show_sudo_dialog=0
+    [ "$(uname)" = "Darwin" ] && show_sudo_dialog=1
 fi
 
 #add all layers to LD_LIBRARY_PATH
@@ -654,6 +531,12 @@ done
 root_nonroot=
 [ "yes" != "${skip_gui_install}" ] && [ "yes" != "${skip_uid_check}" ] && [ $show_sudo_dialog -eq 1 ] && root_nonroot="--RUN_MODE=root_nonroot"
 
+if [ "$UID" -ne 0 ] && [ "yes" != "${minimal_launch}" ] && [ "yes" = "$silent_mode" ] && [ "$pset_mode" = "uninstall" ] && [ $show_sudo_dialog -eq 1 ]; then
+    get_strings
+    echo "$LI_root_permissions_required_warning"
+    exit $EXIT_CODE_CANCEL
+fi
+
 if [ "yes" != "${skip_gui_install}" ]; then
     export QTDIR=
     export QT_PLUGIN_PATH=
@@ -664,11 +547,9 @@ if [ "yes" != "${skip_gui_install}" ]; then
             export XKB_DEFAULT_RULES=base
         fi
     fi
+    check_display
     "$pset_engine_binary" --tmp_dir "$user_tmp" --TEMP_FOLDER "$temp_folder" --download_dir "$download_tmp" $params $root_nonroot 2>/dev/null
     exit_code=$?
-    if [ "yes" = "${root_added_to_xhost_acl}" ]; then
-        remove_root_from_xhost_acl
-    fi
 else
     if [ "$cli_mode_params" = "--cli-mode" ]; then
         check_cli_binary
@@ -684,15 +565,6 @@ if [ "$exit_code" = "$EXIT_CODE_GUI_RUN_ERROR" ] || [ "$exit_code" = "134" ]; th
     skip_gui_install=yes
 fi
 
-if [ "$UID" -ne 0 ] && [ "yes" = "${skip_gui_install}" ] && [ "yes" != "$skip_uid_check" ] && [ $show_sudo_dialog -eq 1 ]; then
-    [ "$(uname)" != "Darwin" ] && [ "yes" != "${minimal_launch}" ] && get_strings
-    if [ "yes" = "$silent_mode" ] && [ "$pset_mode" = "uninstall" ]; then
-        echo "$LI_root_permissions_required_warning"
-        exit $EXIT_CODE_CANCEL
-    fi
-    cli_root_nonroot_dialog
-fi
-
 if [ "yes" = "${skip_gui_install}" ]; then
     if [ ! -z "$pset_engine_cli_binary" ]; then
         "$pset_engine_cli_binary" --tmp_dir "$user_tmp" --TEMP_FOLDER "$temp_folder" --download_dir "$download_tmp" $params
@@ -702,14 +574,11 @@ if [ "yes" = "${skip_gui_install}" ]; then
     fi
 fi
 
+if [ "yes" = "${root_added_to_xhost_acl}" ]; then
+    remove_root_from_xhost_acl
+fi
+
 [ "yes" = "${minimal_launch}" ] && rm -rf $temp_folder >/dev/null 2>&1
 [ "$(uname)" != "Darwin" ] && [ "$pset_mode" = "uninstall" ] && rm -rf $temp_dir >/dev/null 2>&1
 
-## CD Eject Issue
-if [ -f "$fullpath"/cd_eject.sh ]; then
-    if [ -z "$skip_cd_eject" ]; then
-        "$fullpath"/cd_eject.sh $PPID
-        exit $exit_code
-    fi
-fi
 exit $exit_code
