@@ -45,29 +45,29 @@ while [ $# -gt 0 ] ; do
 	shift
 done
 
-PSXE_LOCATION=$PSXE_ROOT/parallel_studio_xe_2018.3.051
-CNL_LOCATION=$CNL_ROOT/compilers_and_libraries_2018.3.222
-ADVISOR_LOCATION=$PSXE_ROOT/advisor_2018
-INSPECTOR_LOCATION=$PSXE_ROOT/inspector_2018
-AMPLIFIER_LOCATION=$PSXE_ROOT/vtune_amplifier_2018
-CLCK_LOCATION=$PSXE_ROOT/clck/2018.3
-ITAC_LOCATION=$PSXE_ROOT/itac/2018.3.022
-IDE_LOCATION=$CNL_ROOT/ide_support_2018
-DOC_LOCATION=$PSXE_ROOT/documentation_2018
-SAMPLES_LOCATION=$PSXE_ROOT/samples_2018
+PSXE_LOCATION=$PSXE_ROOT/parallel_studio_xe_2019.1.053
+CNL_LOCATION=$CNL_ROOT/compilers_and_libraries_2019.1.144
+ADVISOR_LOCATION=$PSXE_ROOT/advisor_2019
+INSPECTOR_LOCATION=$PSXE_ROOT/inspector_2019
+AMPLIFIER_LOCATION=$PSXE_ROOT/vtune_amplifier_2019
+CLCK_LOCATION=$PSXE_ROOT//clck/2019.0
+ITAC_LOCATION=$PSXE_ROOT/itac/2019.1.022
+IDE_LOCATION=$CNL_ROOT/ide_support_2019
+DOC_LOCATION=$PSXE_ROOT/documentation_2019
+SAMPLES_LOCATION=$PSXE_ROOT/samples_2019
 MAN_LOCATION=$CNL_ROOT/man
 
 # <base_directory>	<symlink>	<target>
 LINKS="
-$PSXE_LOCATION	clck_2018	$CLCK_LOCATION
-$PSXE_LOCATION	itac_2018	$ITAC_LOCATION
-$PSXE_LOCATION	advisor_2018	$ADVISOR_LOCATION
-$PSXE_LOCATION	inspector_2018	$INSPECTOR_LOCATION
-$PSXE_LOCATION	vtune_amplifier_2018	$AMPLIFIER_LOCATION
-$PSXE_LOCATION	compilers_and_libraries_2018	$CNL_LOCATION
-$PSXE_LOCATION	documentation_2018	$DOC_LOCATION
-$PSXE_LOCATION	ide_support_2018	$IDE_LOCATION
-$PSXE_LOCATION	samples_2018	$SAMPLES_LOCATION
+$PSXE_LOCATION	clck_2019	$CLCK_LOCATION
+$PSXE_LOCATION	itac_2019	$ITAC_LOCATION
+$PSXE_LOCATION	advisor_2019	$ADVISOR_LOCATION
+$PSXE_LOCATION	inspector_2019	$INSPECTOR_LOCATION
+$PSXE_LOCATION	vtune_amplifier_2019	$AMPLIFIER_LOCATION
+$PSXE_LOCATION	compilers_and_libraries_2019	$CNL_LOCATION
+$PSXE_LOCATION	documentation_2019	$DOC_LOCATION
+$PSXE_LOCATION	ide_support_2019	$IDE_LOCATION
+$PSXE_LOCATION	samples_2019	$SAMPLES_LOCATION
 $PSXE_LOCATION	man	$MAN_LOCATION
 "
 
